#
# spec file for package xl2tpd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} <= 1310
%define rundir %{_localstatedir}/run
%else
%define rundir /run
%endif
Name:           xl2tpd
Version:        1.3.18
Release:        2.4
Summary:        Layer 2 Tunnelling Protocol Daemon (RFC 2661)
License:        GPL-2.0-only
Group:          Productivity/Networking/System
URL:            http://www.xelerance.com/software/xl2tpd/
Source0:        https://github.com/xelerance/xl2tpd/archive/v%{version}.tar.gz
Source1:        %{name}.service
Source2:        %{name}.conf
Patch0:         Makefile.patch
Patch1:         xl2tpd.init.patch
BuildRequires:  libpcap
BuildRequires:  libpcap-devel
BuildRequires:  linux-kernel-headers >= 2.6.19
BuildRequires:  systemd-rpm-macros
Requires:       ppp
Obsoletes:      l2tpd <= 0.68
Provides:       l2tpd = 0.69
%{?systemd_ordering}

%description
xl2tpd is an implementation of the Layer 2 Tunnelling Protocol (RFC 2661).
L2TP allows you to tunnel PPP over UDP. Some ISPs use L2TP to tunnel user
sessions from dial-in servers (modem banks, ADSL DSLAMs) to back-end PPP
servers. Another important application is Virtual Private Networks where
the IPsec protocol is used to secure the L2TP connection (L2TP/IPsec,
RFC 3193). The L2TP/IPsec protocol is mainly used by Windows and
Mac OS X clients. On Linux, xl2tpd can be used in combination with IPsec
implementations such as Openswan.
Example configuration files for such a setup are included in this RPM.

xl2tpd works by opening a pseudo-tty for communicating with pppd.
It runs completely in userspace but supports kernel mode L2TP.

xl2tpd supports IPsec SA Reference tracking to enable overlapping internak
NAT'ed IP's by different clients (eg all clients connecting from their
linksys internal IP 192.168.1.101) as well as multiple clients behind
the same NAT router.

xl2tpd supports the pppol2tp kernel mode operations on 2.6.23 or higher,
or via a patch in contrib for 2.4.x kernels.

Xl2tpd is based on the 0.69 L2TP by Jeff McAdams <jeffm@iglou.com>
It was de-facto maintained by Jacco de Leeuw <jacco2@dds.nl> in 2002 and 2003.

%prep
%autosetup -p0

%build
make %{?_smp_mflags} DFLAGS="%{optflags} -D_GNU_SOURCE $(getconf LFS_CFLAGS)"

%install
export PREFIX=%{_prefix}
%make_install
install -p -D -m644 examples/xl2tpd.conf %{buildroot}%{_sysconfdir}/xl2tpd/xl2tpd.conf
install -p -d -m750 %{buildroot}%{_sysconfdir}/ppp
install -p -D -m644 examples/ppp-options.xl2tpd %{buildroot}%{_sysconfdir}/ppp/options.xl2tpd
install -p -D -m600 doc/l2tp-secrets.sample %{buildroot}%{_sysconfdir}/xl2tpd/l2tp-secrets
install -p -D -m600 examples/chapsecrets.sample %{buildroot}%{_sysconfdir}/ppp/chap-secrets.sample
install -p -D -m755 -d %{buildroot}%{rundir}/xl2tpd
install -D -m0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -D -m0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%if 0%{?suse_version} > 1310
sed -i 's|%{_localstatedir}/run/|/run/|' %{buildroot}%{_tmpfilesdir}/%{name}.conf
%endif
mkdir -p %{buildroot}%{_prefix}/lib/modules-load.d
echo "l2tp_ppp" > %{buildroot}%{_prefix}/lib/modules-load.d/%{name}.conf
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
# if we migrate from l2tpd to xl2tpd, copy the configs
if [ -f %{_sysconfdir}/l2tpd/l2tpd.conf ]
then
	echo "Old %{_sysconfdir}/l2tpd configuration found, migrating to %{_sysconfdir}/xl2tpd"
	mv %{_sysconfdir}/xl2tpd/xl2tpd.conf %{_sysconfdir}/xl2tpd/xl2tpd.conf.rpmsave
	cat %{_sysconfdir}/l2tpd/l2tpd.conf | sed "s/options.l2tpd/options.xl2tpd/" > %{_sysconfdir}/xl2tpd/xl2tpd.conf
	mv %{_sysconfdir}/ppp/options.xl2tpd %{_sysconfdir}/ppp/options.xl2tpd.rpmsave
	mv %{_sysconfdir}/ppp/options.l2tpd %{_sysconfdir}/ppp/options.xl2tpd
	mv %{_sysconfdir}/xl2tpd/l2tp-secrets %{_sysconfdir}/xl2tpd/l2tpd-secrets.rpmsave
	cp -pa %{_sysconfdir}/l2tpd/l2tp-secrets %{_sysconfdir}/xl2tpd/l2tp-secrets

fi

%service_add_post %{name}.service
%fillup_only
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license LICENSE
%doc BUGS CHANGES CREDITS README.* TODO
%doc doc/README.patents examples/chapsecrets.sample
%{_sbindir}/rcxl2tpd
%{_sbindir}/xl2tpd
%{_sbindir}/xl2tpd-control
%{_bindir}/pfc
%dir %{_sysconfdir}/xl2tpd
%config(noreplace) %{_sysconfdir}/xl2tpd/*
%dir %{_sysconfdir}/ppp
%config(noreplace) %{_sysconfdir}/ppp/*
%dir %ghost %{rundir}/xl2tpd
%ghost %{rundir}/xl2tpd/l2tp-control
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service
%dir %{_prefix}/lib/modules-load.d
%{_prefix}/lib/modules-load.d/%{name}.conf
%{_mandir}/man1/pfc.1%{?ext_man}
%{_mandir}/man5/l2tp-secrets.5%{?ext_man}
%{_mandir}/man5/xl2tpd.conf.5%{?ext_man}
%{_mandir}/man8/xl2tpd-control.8%{?ext_man}
%{_mandir}/man8/xl2tpd.8%{?ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Nov  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.18
  * Add compatability information for Watchguard Firewall.
  * Fix issue where in some cases xl2tpd stops trying to connect
    if it can not resolve server name (DNS failure or WAN
    temporarily unavailable), even if autodial and redial options
    are set.
* Sun Mar 27 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.17
  * Correct a typo in the man page xl2tpd.conf(5)
  * xl2tpd-control: fix typo in usage
* Mon Jan 10 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * xl2tpd.service
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 1.3.16:
  * Re-add braces for if-else that have only statement [Samir Hussain]
  * xl2tpd-control refactoring [Alexander Naumov]
  * fix travis 'script' syntax [Alexander Naumov]
  * adding xl2tpd-control tests to travis [Alexander Naumov]
  * Re-adding text giving more inofrmation about using ipsec with xl2tpd [Samir Hussain]
  * Update README: typo, links to RFC, link to travis [Alexander Naumov]
  * Travis will test different compiler on linux distro [Samir Hussain]
  * Update travis for proper matrix [Samir Hussain]
  * Add Focal to travis testing [Samir Hussain]
  * yet another man-page update [Alexander Naumov]
  * update man-pages, fix typo [Alexander Naumov]
  * set_flow: result of operation is garbage or undefined [Alexander Naumov]
  * Update README [Alexander Naumov]
  * adding xl2tpd.init.patch [Alexander Naumov]
  * adding Makefile.patch [Alexander Naumov]
  * moving changes to separate file [Alexander Naumov]
  * sync/update spec file with official SUSE version [Alexander Naumov]
  * Set IP_PKTINFO even if setting of IPPROTO_IP fails (as it was in 1.3.9) [shadyhh]
  * Update .gitignore vim swap file [Samir Hussain]
  * Travis will test supported Ubuntu LTS distros [Samir Hussain]
  * Updating COMPATABILITY_ISSUES with info on Miktrotik servers [Samir Hussain]
  * Add work around for Android 10 maxium retries in COMPATIBILITY_ISSUES [Samir Hussain]
  * Add compatability issues with Ciso ASA [Samir Hussain]
* Sun Oct 13 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.15
  * Specify missing log arguments
  * Sockopt bug fix for multiple IP's
* Wed Apr 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.14
  * Bugfix release, mostly code cleanup
* Wed Mar 20 2019 Jan Engelhardt <jengelh@inai.de>
- Drop ||true from %%tmpfiles_create, this is already
  included in the macro.
- Reduce hard dependency on systemd during build.
* Fri Mar  8 2019 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Remove support for non-systemd distros
- Remove -doc subpackage (contained only some KB text-files and
  and manpages)
- Fix handling of tmpfilesdir
- Update to version 1.3.13
  * Fix compile warning with USE_KERNEL in xl2tpd.c
  * Applying patch that reduces compile warnings and fixes warnings
    from gcc and clang.
  * Fix compiler warnings in network.c
  * Add a preproc for Watchguard firewall (Github issue #136)
  * Convert from ISO-8859 to UTF-8 [Simon Deziel]
    Update README to provide latest info on xl2tpd + Linux kernel 4.15+
- Update to version 1.3.12
  * TOS value to copy to the tunnel header
  * Fix for ENODEV (No such device) error with Linux kernel 4.15
  * Update xl2tpd.init
  * fix version number and upload
- Update to version 1.3.11
  * only changes related to debian packaging
* Thu Oct 26 2017 badshah400@gmail.com
- Update to version 1.3.10
  * Update STRLEN in file.h to 100 (from 80).
  * xl2tpd-control: fix xl2tpd hanged up in "fopen".
  * Update version in spec and opewnrt Makefile.
- Update source URL in specfile.
* Thu Jun 29 2017 dimstar@opensuse.org
- Own /etc/ppp (mode 750, like other packages too).
* Tue May 16 2017 alexander_naumov@opensuse.org
- Update to version 1.3.9
  * Add xl2tpd-control man pages (Samir Hussain)
  * Update spec file with newest Soure0 and version (Samir Hussain)
  * Update License file (Samir Hussain)
  * Display PID for call in the logs (Samir Hussain)
  * Use left shift rather than pow() function. (Samir Hussain)
  * Enable Travis integration (Samir Hussain)
  * Remove unnecessary casting of malloc() results (Andrew Clayton)
  * Remove an unused line of code in init_config() (Andrew Clayton)
  * Fix some undefined behaviour in read_result() (Andrew Clayton)
  * Fix feature test macro deprecation warnings (Andrew Clayton)
* Sun Apr 12 2015 p.drouand@gmail.com
- Update to version 1.3.6
  * Fix the size of the lenght param for AVP headers. This should
    fix Android support no matter how the compiler optimizes.
- For changes from other versions, please read the CHANGES files
- Use download Url as source
- Remove redundant %%clean section
- Remove xl2tpd-1.3.0-0001-Add-kernel-support-for-2.6.32.patch;
  fixed by upstream
- Adapt Makefile.patch and xl2tpd.init.patch to upstream changes
- Do not provide sysvinit and systemd support on the same system;
  it's redundant
- Add backward compatibility symlinl to systemd service
* Thu Jun 26 2014 dvlaeev@suse.com
- switch to /run on openSUSE newer than 13.1
* Wed Jan  1 2014 dvlaeev@suse.com
- Remove newline from description in xl2tpd.conf (bnc#856928)
* Sun Mar 17 2013 dvaleev@suse.com
- Use /usr/lib/tmpfile.d for tmpfiles configuration
* Wed Mar  6 2013 avm.xandry@gmail.com
- Added /etc/tmpfiles.d/xl2tpd.conf file (bnc#807605)
* Mon Nov 26 2012 dvaleev@suse.com
- don't use old version of if_pppol2tp.h (bnc#791109)
* Wed Nov 21 2012 binli@opensuse.org
- xl2tpd Add kernel support for 2.6.23+ (patch v12)
  xl2tpd-1.3.0-0001-Add-kernel-support-for-2.6.32.patch
  Public Clone URL: git://gist.github.com/1306094.git
  (bnc#790250).
* Fri Aug 31 2012 crrodriguez@opensuse.org
- Add systemd support.
* Wed Oct 26 2011 nekolayer@yandex.ru
- update to xl2tpd 1.3.0
  * added xl2tpd-control tool (activates/disconnects the tunnel,
  actions with lac configuration file)
  * fixed bug causing "Resource temporarily unavailable(11)" in log
  * fixed xl2tpd hungs and won't redial after communication fail
  * fixed buffer overrun in reading >16 char l2tp-secrets
* Tue May  4 2010 dvaleev@novell.com
- fixed rpmlint dir-or-file-in-var-run
* Thu Apr 22 2010 aj@suse.de
- Fix specfile, debug_package will get inserted automatically.
- Do not use license package.
* Fri Apr 16 2010 eri_zaq@please-enter-an-email-address
- xl2tpd-1.2.4-4
- Fix init script to stop service correctly
- *.changes
* Sun Mar 14 2010 k0da@opensuse.org
- xl2tpd-1.2.4-3
- avoid a huge overload of duplicated files
* Wed Mar 10 2010 k0da@opensuse.org
- xl2tpd-1.2.4-2
- xl2tpd-doc-1.2.4-2
- *-doc package
- cleanup init script
* Tue Mar  9 2010 k0da@opensuse.org
- xl2tpd-1.2.4-1
- patch for init file
* Mon Oct 27 2008 k0da@opensuse.org
- Adjust build requires
* Sat Oct 25 2008 paul@xelerance.com
- Updated Suse init scripts and spec file
- Added pfc for pppd's precompiled-active-filter
* Thu Apr 17 2008 paul@xelerance.com
- Updated Suse init scripts and spec file
* Mon Jun 25 2007 paul@xelerance.com
- Minor changes to spec file to accomodate new README files
* Thu Feb 22 2007 paul@xelerance.com
- Upgraded to 1.1.08
- This works around the ppp-2.4.2-6.4 issue of not dying on SIGTERM
* Sun Feb 18 2007 paul@xelerance.com
- Upgraded to 1.1.07
- Fixes from Tuomo Soini for pidfile handling with Fedora
- Fix hardcoded version for Source in spec file.
* Wed Dec  6 2006 paul@xelerance.com
- Changed space/tab replacing method
* Tue Dec  5 2006 paul@xelerance.com
- Added -p to keep original timestamps
- Added temporary hack to change space/tab in init file.
- Added /sbin/service dependancy
* Mon Dec  4 2006 paul@xelerance.com
- Changed Mr. Karlsen's name to not be a utf8 problem
- Fixed Obosoletes/Provides to be more specific wrt l2tpd.
- Added dist tag which accidentally got deleted.
* Sun Dec  3 2006 paul@xelerance.com
- Rebased spec file on Fedora Extras copy, but using xl2tpd as package name
* Sat Nov 26 2005 paul@xelerance.com
- Pulled up sourceforget.net CVS fixes.
- various debugging added, but debugging should not be on by default.
- async/sync conversion routines must be ready for possibility that the read
  will block due to routing loops.
- refactor control socket handling.
- move all logic about pty usage to pty.c. Try ptmx first, if it fails try
  legacy ptys
- rename log() to l2tp_log(), as "log" is a math function.
- if we aren't deamonized, then log to stderr.
- added install: and DESTDIR support.
* Wed Oct 19 2005 paul@xelerance.com
- Removed suse/mandrake specifics. Comply for Fedora Extras guidelines
* Mon Jun 20 2005 jacco2@dds.nl
- Added log() patch by Paul Wouters so that l2tpd compiles on FC4.
* Fri Jun  3 2005 jacco2@dds.nl
- l2tpd.org has been hijacked. Project moved back to SourceForge:
  http://l2tpd.sourceforge.net
* Mon May  2 2005 jacco2@dds.nl
- Small Makefile fixes. Explicitly use gcc instead of cc.
  Network services library was not linked on Solaris due to typo.
* Wed Mar 16 2005 jacco2@dds.nl
- Choosing between SysV or BSD style ptys is now configurable through
  a compile-time boolean "unix98pty".
* Thu Feb  3 2005 jacco2@dds.nl
- Added code from Roaring Penguin (rp-l2tp) to support SysV-style ptys.
  Requires the N_HDLC kernel module.
* Thu Nov 25 2004 jacco2@dds.nl
- Updated the README.
* Tue Nov  9 2004 jacco2@dds.nl
- Patch by Marald Klein and Roger Luethi. Fixes writing PID file.
  (http://l2tpd.graffl.net/msg01790.html)
  Long overdue. Rereleasing 10jdl.
* Mon Nov  8 2004 jacco2@dds.nl
- [SECURITY FIX] Added fix from Debian because of a bss-based
  buffer overflow.
  (http://www.mail-archive.com/l2tpd-devel@l2tpd.org/msg01071.html)
- Mandrake's FreeS/WAN, Openswan and Strongswan RPMS use configuration
  directories /etc/{freeswan,openswan,strongswan}. Install our
  configuration files to /etc/ipsec.d and create symbolic links in
  those directories.
* Tue Aug 17 2004 jacco2@dds.nl
- Removed 'leftnexthop=' lines. Not relevant for recent versions
  of FreeS/WAN and derivates.
* Mon Jan 19 2004 jacco2@dds.nl
- Added "noccp" because of too much MPPE/CCP messages sometimes.
* Tue Dec 30 2003 jacco2@dds.nl
- Added patch in order to prevent StopCCN messages.
* Fri Aug 22 2003 jacco2@dds.nl
- MTU/MRU 1410 seems to be the lowest possible for MSL2TP.
  For Windows 2000/XP it doesn't seem to matter.
- Typo in l2tpd.conf (192.168.128/25).
* Thu Aug  7 2003 jacco2@dds.nl
- Added MTU/MRU 1400 to options.l2tpd. I don't know the optimal
  value but some apps had problems with the default value.
* Thu Jul 31 2003 jacco2@dds.nl
- Added workaround for the missing hostname bug in the MSL2TP client
  ('Specify your hostname', error 629: "You have been disconnected
  from the computer you are dialing").
* Sat Jul 19 2003 jacco2@dds.nl
- Added the "listen-addr" global parameter for l2tpd.conf. By
  default, the daemon listens on *all* interfaces. Use
  "listen-addr" if you want it to bind to one specific
  IP address (interface), for security reasons. (See also:
  http://www.jacco2.dds.nl/networking/freeswan-l2tp.html#Firewallwarning)
- Explained in l2tpd.conf that two different IP addresses should be
  used for 'listen-addr' and 'local ip'.
- Modified init script. Upgrades should work better now. You
  still need to start/chkconfig l2tpd manually.
- Renamed the example Openswan .conf files to better reflect
  the situation. There are two variants using different portselectors.
  Previously I thought Windows 2000/XP used portselector 17/0
  and the rest used 17/1701. But with the release of an updated
  IPsec client by Microsoft, it turns out that 17/0 must have
  been a mistake: the updated client now also uses 17/1701.
* Wed Apr  9 2003 jacco2@dds.nl
- Changed sample chap-secrets to be valid only for specific
  IP addresses.
* Wed Mar 12 2003 tech-role@tronicplanet.de
- Adjustments for SuSE8.x (thanks, Bernhard!)
- Added sample chap-secrets.
* Wed Mar  5 2003 jacco2@dds.nl
- Replaced Dominique's patch by Damion de Soto's, which does not
  depend on the N_HDLC kernel module.
* Tue Feb 25 2003 jacco2@dds.nl
- Seperate example config files for Win9x (MSL2TP) and Win2K/XP
  due to left/rightprotoport differences.
  Fixing preun for Red Hat.
* Sun Feb  2 2003 jacco2@dds.nl
- Mandrake uses /etc/freeswan/ instead of /etc/ipsec.d/
  Error fixed: source6 was used for both PSK and CERT.
* Tue Jan 28 2003 jacco2@dds.nl
- Added Dominique Cressatti's pty patch in another attempt to
  prevent the Windows 2000 Professional "loopback detected" error.
  Seems to work!
* Tue Dec 24 2002 jacco2@dds.nl
- Added 'connect-delay' to PPP parameters in an attempt to
  prevent the Windows 2000 Professional "loopback detected" error.
  Didn't seem to work.
* Thu Dec 12 2002 jacco2@dds.nl
- Did not build on Red Hat 8.0. Solved by adding comments(?!).
  Bug detected in spec file: chkconfig --list l2tpd does not work
  on Red Hat 8.0. Not important enough to look into yet.
* Sat Nov 16 2002 jacco2@dds.nl
- Tested on Red Hat, required some changes. No gprintf. Used different
  pty patch, otherwise wouldn't run. Added buildroot sanity check.
* Sat Nov  9 2002 jacco2@dds.nl
- Specfile adapted from Mandrake Cooker. The original RPM can be
  retrieved through:
  http://www.rpmfind.net/linux/rpm2html/search.php?query=l2tpd
- Config path changed from /etc/l2tp/ to /etc/l2tpd/
  (Seems more logical and rp-l2tp already uses /etc/l2tp/).
- Do not run at boot or install. The original RPM uses a config file
  which is completely commented out, but it still starts l2tpd on all
  interfaces. Could be a security risk. This RPM does not start l2tpd,
  the sysadmin has to edit the config file and start l2tpd explicitly.
- Renamed patches to start with l2tpd-
- Added dependencies for pppd, glibc-devel.
- Use %%%%{name} as much as possible.
- l2tp-secrets contains passwords, thus should not be world readable.
- Removed dependency on rpm-helper.
* Sun Oct 20 2002 lenny@mandrakesoft.com
- from Per 0yvind Karlsen <peroyvind@delonic.no> :
  - PreReq and Requires
  - Fix preun_service
* Wed Oct 16 2002 peroyvind@delonic.no
- Initial release
